mpservice
=========

The package ``mpservice`` provides classes for serving, stream processing, and some related utilities.
The central theme is concurrency by threads or processes.

Read the `documentation <https://mpservice.readthedocs.io/en/latest/>`_.

To install, do

::
    
    python3 -m pip install mpservice

Status
======

Production ready. Under active development.
